@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ApplyCertificate", params)
+            headers = request.headers
+            body = self.call("ApplyCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ApplyCertificateResponse()
@@ -64,7 +65,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CancelCertificateOrder", params)
+            headers = request.headers
+            body = self.call("CancelCertificateOrder", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CancelCertificateOrderResponse()
@@ -92,7 +94,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckCertificateChain", params)
+            headers = request.headers
+            body = self.call("CheckCertificateChain", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckCertificateChainResponse()
@@ -120,7 +123,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CommitCertificateInformation", params)
+            headers = request.headers
+            body = self.call("CommitCertificateInformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CommitCertificateInformationResponse()
@@ -148,7 +152,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CompleteCertificate", params)
+            headers = request.headers
+            body = self.call("CompleteCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CompleteCertificateResponse()
@@ -176,7 +181,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateCertificate", params)
+            headers = request.headers
+            body = self.call("CreateCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateCertificateResponse()
@@ -204,7 +210,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteCertificate", params)
+            headers = request.headers
+            body = self.call("DeleteCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteCertificateResponse()
@@ -232,7 +239,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteManager", params)
+            headers = request.headers
+            body = self.call("DeleteManager", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteManagerResponse()
@@ -260,7 +268,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCertificate", params)
+            headers = request.headers
+            body = self.call("DescribeCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCertificateResponse()
@@ -288,7 +297,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCertificateDetail", params)
+            headers = request.headers
+            body = self.call("DescribeCertificateDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCertificateDetailResponse()
@@ -316,7 +326,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCertificateOperateLogs", params)
+            headers = request.headers
+            body = self.call("DescribeCertificateOperateLogs", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCertificateOperateLogsResponse()
@@ -344,7 +355,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeCertificates", params)
+            headers = request.headers
+            body = self.call("DescribeCertificates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeCertificatesResponse()
@@ -362,6 +374,35 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDeployedResources(self, request):
+        """证书查询关联资源
+
+        :param request: Request instance for DescribeDeployedResources.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeDeployedResourcesRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.DescribeDeployedResourcesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDeployedResources", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDeployedResourcesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeManagerDetail(self, request):
         """查询管理人详情
 
@@ -372,7 +413,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeManagerDetail", params)
+            headers = request.headers
+            body = self.call("DescribeManagerDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeManagerDetailResponse()
@@ -400,7 +442,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeManagers", params)
+            headers = request.headers
+            body = self.call("DescribeManagers", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeManagersResponse()
@@ -428,7 +471,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DownloadCertificate", params)
+            headers = request.headers
+            body = self.call("DownloadCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DownloadCertificateResponse()
@@ -446,6 +490,35 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def HostCertificate(self, request):
+        """云资源托管
+
+        :param request: Request instance for HostCertificate.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.HostCertificateRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.HostCertificateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("HostCertificate", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.HostCertificateResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyCertificateAlias(self, request):
         """用户传入证书id和备注来修改证书备注。
 
@@ -456,7 +529,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyCertificateAlias", params)
+            headers = request.headers
+            body = self.call("ModifyCertificateAlias", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyCertificateAliasResponse()
@@ -484,7 +558,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyCertificateProject", params)
+            headers = request.headers
+            body = self.call("ModifyCertificateProject", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyCertificateProjectResponse()
@@ -512,7 +587,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ReplaceCertificate", params)
+            headers = request.headers
+            body = self.call("ReplaceCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ReplaceCertificateResponse()
@@ -540,7 +616,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("RevokeCertificate", params)
+            headers = request.headers
+            body = self.call("RevokeCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.RevokeCertificateResponse()
@@ -568,7 +645,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SubmitAuditManager", params)
+            headers = request.headers
+            body = self.call("SubmitAuditManager", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SubmitAuditManagerResponse()
@@ -596,7 +674,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SubmitCertificateInformation", params)
+            headers = request.headers
+            body = self.call("SubmitCertificateInformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SubmitCertificateInformationResponse()
@@ -624,7 +703,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadCertificate", params)
+            headers = request.headers
+            body = self.call("UploadCertificate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadCertificateResponse()
@@ -652,7 +732,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadConfirmLetter", params)
+            headers = request.headers
+            body = self.call("UploadConfirmLetter", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadConfirmLetterResponse()
@@ -680,7 +761,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UploadRevokeLetter", params)
+            headers = request.headers
+            body = self.call("UploadRevokeLetter", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UploadRevokeLetterResponse()
@@ -708,7 +790,8 @@ class SslClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("VerifyManager", params)
+            headers = request.headers
+            body = self.call("VerifyManager", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.VerifyManagerResponse()
