@@ -18,13 +18,205 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class FileTranslateRequest(AbstractModel):
+    """FileTranslate请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Source: 源语言，支持
+zh:简体中文
+zh-HK：繁体中文
+zh-TW : 繁体中文
+zh-TR:  繁体中文
+en ：英语
+ar：阿拉伯语
+de：德语
+es：西班牙语
+fr：法语
+it：意大利语
+ja：日语
+pt：葡萄牙语
+ru：俄语
+ko：韩语
+km：高棉语
+lo：老挝语
+        :type Source: str
+        :param Target: 目标语言，各源语言的目标语言支持列表如下
+zh（简体中文）： en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
+zh-HK（繁体中文） ：en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
+zh-TW（繁体中文）：en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
+zh-TR 繁体中文 : en （英语）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
+en （英语） ：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、 zh-TR(繁体中文）、 ar (阿拉伯语）、 de （德语）、  es（西班牙语） 、fr（法语）、  it（意大利语） 、 ja （日语）、 pt （葡萄牙语）、 ru（俄语）、  ko（韩语）、 km（高棉语）、   lo（老挝语）
+ar（阿拉伯语） ：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+de（德语 ）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+es（西班牙语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+fr（法语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+it（意大利语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+ja（日语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+pt（葡萄牙语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+ru（俄语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+ko（韩语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+km（高棉语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+lo（老挝语）：zh（简体中文）、zh-HK（繁体中文）、 zh-TW（繁体中文)、zh-TR(繁体中文）
+        :type Target: str
+        :param DocumentType: 文档类型：可支持以下几种(pdf,docx,pptx,xlsx,txt,xml,html,markdown,properties)
+        :type DocumentType: str
+        :param SourceType: 数据来源，0：url，1：直接传文件编码后数据
+        :type SourceType: int
+        :param Url: 需要翻译文件url
+        :type Url: str
+        :param BasicDocumentType: 原始文档类型
+        :type BasicDocumentType: str
+        :param CallbackUrl: 回调url
+        :type CallbackUrl: str
+        :param Data: 文件数据，当SourceType 值为1时必须填写，为0可不写。要base64编码(采用python语言时注意读取文件应该为string而不是byte，以byte格式读取后要decode()。编码后的数据不可带有回车换行符)。数据要小于5MB。
+        :type Data: str
+        """
+        self.Source = None
+        self.Target = None
+        self.DocumentType = None
+        self.SourceType = None
+        self.Url = None
+        self.BasicDocumentType = None
+        self.CallbackUrl = None
+        self.Data = None
+
+
+    def _deserialize(self, params):
+        self.Source = params.get("Source")
+        self.Target = params.get("Target")
+        self.DocumentType = params.get("DocumentType")
+        self.SourceType = params.get("SourceType")
+        self.Url = params.get("Url")
+        self.BasicDocumentType = params.get("BasicDocumentType")
+        self.CallbackUrl = params.get("CallbackUrl")
+        self.Data = params.get("Data")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class FileTranslateResponse(AbstractModel):
+    """FileTranslate返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Data: 文件翻译的请求返回结果，包含结果查询需要的TaskId
+        :type Data: :class:`tencentcloud.tmt.v20180321.models.Task`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = Task()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
+class GetFileTranslateData(AbstractModel):
+    """查询文件翻译任务
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: 任务ID
+        :type TaskId: str
+        :param Status: 状态
+        :type Status: str
+        :param FileData: 文件数据
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FileData: str
+        :param Message: 错误提示
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Message: str
+        """
+        self.TaskId = None
+        self.Status = None
+        self.FileData = None
+        self.Message = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        self.Status = params.get("Status")
+        self.FileData = params.get("FileData")
+        self.Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class GetFileTranslateRequest(AbstractModel):
+    """GetFileTranslate请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: 任务ID
+        :type TaskId: str
+        """
+        self.TaskId = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class GetFileTranslateResponse(AbstractModel):
+    """GetFileTranslate返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Data: 任务id
+        :type Data: :class:`tencentcloud.tmt.v20180321.models.GetFileTranslateData`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = GetFileTranslateData()
+            self.Data._deserialize(params.get("Data"))
+        self.RequestId = params.get("RequestId")
+
+
 class ImageRecord(AbstractModel):
     """图片翻译结果
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Value: 图片翻译结果
         :type Value: list of ItemValue
         """
@@ -53,7 +245,7 @@ class ImageTranslateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SessionUuid: 唯一id，返回时原样返回
         :type SessionUuid: str
         :param Scene: doc:文档扫描
@@ -111,7 +303,7 @@ class ImageTranslateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SessionUuid: 请求的SessionUuid返回
         :type SessionUuid: str
         :param Source: 源语言
@@ -146,7 +338,7 @@ class ItemValue(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SourceText: 识别出的源文
         :type SourceText: str
         :param TargetText: 翻译后的译文
@@ -190,7 +382,7 @@ class LanguageDetectRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Text: 待识别的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败。单次请求的文本长度需要低于2000。
         :type Text: str
         :param ProjectId: 项目ID，可以根据控制台-账号中心-项目管理中的配置填写，如无配置请填写默认项目ID:0
@@ -218,7 +410,7 @@ class LanguageDetectResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Lang: 识别出的语言种类，参考语言列表
 <li> zh : 中文 </li> <li> en : 英文 </li><li> jp : 日语 </li> <li> kr : 韩语 </li><li> de : 德语 </li><li> fr : 法语 </li><li> es : 西班牙文 </li> <li> it : 意大利文 </li><li> tr : 土耳其文 </li><li> ru : 俄文 </li><li> pt : 葡萄牙文 </li><li> vi : 越南文 </li><li> id : 印度尼西亚文 </li><li> ms : 马来西亚文 </li><li> th : 泰文 </li>
         :type Lang: str
@@ -240,7 +432,7 @@ class SpeechTranslateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SessionUuid: 一段完整的语音对应一个SessionUuid
         :type SessionUuid: str
         :param Source: 音频中的语言类型，支持语言列表<li> zh : 中文 </li> <li> en : 英文 </li>
@@ -300,7 +492,7 @@ class SpeechTranslateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SessionUuid: 请求的SessionUuid直接返回
         :type SessionUuid: str
         :param RecognizeStatus: 语音识别状态 1-进行中 0-完成
@@ -343,13 +535,37 @@ class SpeechTranslateResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class Task(AbstractModel):
+    """文件翻译请求的返回数据
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TaskId: 任务ID，可通过此ID在轮询接口获取识别状态与结果。注意：TaskId数据类型为字符串类型
+        :type TaskId: str
+        """
+        self.TaskId = None
+
+
+    def _deserialize(self, params):
+        self.TaskId = params.get("TaskId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class TextTranslateBatchRequest(AbstractModel):
     """TextTranslateBatch请求参数结构体
 
     """
 
     def __init__(self):
-        """
+        r"""
         :param Source: 源语言，支持： 
 auto：自动识别（识别为一种语言）
 zh：简体中文
@@ -423,7 +639,7 @@ class TextTranslateBatchResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Source: 源语言，详见入参Target
         :type Source: str
         :param Target: 目标语言，详见入参Target
@@ -452,7 +668,7 @@ class TextTranslateRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SourceText: 待翻译的文本，文本统一使用utf-8格式编码，非utf-8格式编码字符会翻译失败，请传入有效文本，html标记等非常规翻译文本可能会翻译失败。单次请求的文本长度需要低于2000。
         :type SourceText: str
         :param Source: 源语言，支持：
@@ -530,7 +746,7 @@ class TextTranslateResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param TargetText: 翻译后的文本
         :type TargetText: str
         :param Source: 源语言，详见入参Target
